#include "graphics.hpp"
#include <stdio.h>
#include <stdlib.h>
#include <bios.h>

Graphics::Graphics()
{
	if (fg_init() == FG_NULL) {
	  fg_term();
	  puts("\nUnable to open graphics device");
	  exit(1);
	}
}

void Graphics::DrawDot(COLOR_TYPE color, int x, int y)
{
	fg_drawdot( (fg_color_t) color, FG_MODE_SET, ~0, x, y);
}


void Graphics::DrawBox(COLOR_TYPE color, LINE_STYLE style, BOX_TYPE* box)
{
	fg_drawbox( (fg_color_t) color, FG_MODE_SET, ~0,
		    style,
		    (fg_const_pbox_t) box,
		    fg.displaybox);
}


void Graphics::DrawCircle(COLOR_TYPE color,
			  LINE_STYLE style,
			  int x, int y, int radius)
{
	fg_drawarc( (fg_color_t) color, FG_MODE_SET, ~0,
		    (fg_coord_t) x,
		    (fg_coord_t) y,
		    (fg_coord_t) radius,
		    0, 3600,
		    fg.displaybox);
}


void Graphics::DrawLine(COLOR_TYPE color, LINE_STYLE type, BOX_TYPE* box)
{
	fg_drawline( (fg_color_t) color, FG_MODE_SET, ~0,
		    FG_LINE_SOLID,
		    (fg_const_pline_t) box);
}


void Graphics::FillBox(COLOR_TYPE color, BOX_TYPE* box)
{
	fg_fillbox( (fg_color_t) color, FG_MODE_SET, ~0,
		    (fg_const_pbox_t) box);
}


void Graphics::FillCircle(COLOR_TYPE color, int x, int y, int radius)
{
	// draw the border of the circle
	DrawCircle(color, SOLID_LINE, x + radius, y + radius, radius);

	//now fill the inside
	fg_fill(x + radius,
		y + radius,
		(fg_color_t) color,
		(fg_color_t) color);
}


void Graphics::PutString(COLOR_TYPE color, int x, int y, char* string)
{
	fg_puts( (fg_color_t) color, FG_MODE_SET, ~0, FG_ROT0, x, y,
		    string, fg.displaybox);
}


int Graphics::FontWidth()
{
	return (fg.charbox [FG_X2] + 1);
}


int Graphics::FontHeight()
{
	return (fg.charbox [FG_Y2] + 1);
}

int Graphics::ScreenWidth()
{
	return fg.displaybox [FG_X2];
}

int Graphics::ScreenHeight()
{
	return fg.displaybox [FG_Y2];
}

void Graphics::Terminate()
{
	// exit graphics mode
	fg_term();
}

Graphics::~Graphics()
{
	// close the graphics mode
	Terminate();
}

